@@ -1,4 +1,4 @@
-# Copyright © 2013-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2013-2023 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -25,6 +25,7 @@ the command-line interface
 import argparse
 import functools
 import io
+import re
 import signal
 import sys
 import types
@@ -41,7 +42,7 @@ class lib:
     from . import text
     # pylint: enable=import-outside-toplevel
 
-__version__ = '0.7.8'
+__version__ = '0.7.10'
 
 class VersionAction(argparse.Action):
 
@@ -54,9 +55,10 @@ class VersionAction(argparse.Action):
         )
 
     def __call__(self, parser, namespace, values, option_string=None):
-        print('{prog} {0}'.format(__version__, prog=parser.prog))
+        # pylint: disable=consider-using-f-string
+        print(f'{parser.prog} {__version__}')
         print('+ Python {0}.{1}.{2}'.format(*sys.version_info))
-        print('+ PyEnchant {0}'.format(__version__))
+        print(f'+ PyEnchant {enchant.__version__}')
         try:
             enchant_version = enchant.get_enchant_version()
         except AttributeError:
@@ -64,9 +66,9 @@ class VersionAction(argparse.Action):
         else:
             if isinstance(enchant_version, bytes):
                 enchant_version = enchant_version.decode('ASCII', 'replace')
-            print('  + Enchant {0}'.format(enchant_version))
+            print(f'  + Enchant {enchant_version}')
         regex = lib.intdict.re
-        print('+ regex {0}'.format(regex.__version__))  # pylint: disable=no-member
+        print(f'+ regex {regex.__version__}')  # pylint: disable=no-member
         parser.exit()
 
 def main():
@@ -98,7 +100,7 @@ def main():
         help='omit blank lines in output')
     ap.add_argument('--limit', metavar='N', type=int, default=1e999,
         help='skip words that have >N instances')
-    ap.add_argument('--max-context-width', metavar='N', default=30,
+    ap.add_argument('--max-context-width', type=int, metavar='N', default=30,
         help='limit context width to N chars')
     ap.add_argument('--suggest', metavar='N', type=int, default=0,
         help='suggest up to N corrections')
@@ -127,7 +129,7 @@ def main():
         else:
             dictvars = vars(dictionary).items()
         for key, value in sorted(dictvars):
-            print('{k} = {v!r}'.format(k=key, v=value))
+            print(f'{key} = {value!r}')
         sys.exit(0)
     intdict = lib.intdict.Dictionary(options.language)
     extdict = lib.extdict.Dictionary(*options.blacklist)
@@ -155,7 +157,7 @@ def main():
             )
         else:
             try:
-                file = open(
+                file = open(  # pylint: disable=consider-using-with
                     path, 'rt',
                     encoding=encoding,
                     errors=enc_errors,
@@ -163,7 +165,7 @@ def main():
             except OSError as exc:
                 if options.traceback:
                     raise
-                msg = '{prog}: {path}: {exc}'.format(prog=ap.prog, path=path, exc=exc.strerror)
+                msg = f'{ap.prog}: {path}: {exc.strerror}'
                 print(msg, file=sys.stderr)
                 rc = 1
                 continue
@@ -172,8 +174,15 @@ def main():
     if not misspellings:
         sys.exit(rc)
     raw_cc = options.output_format == 'color'
-    with lib.pager.autopager(raw_control_chars=raw_cc):
-        print_misspellings(ctxt)
+    try:
+        with lib.pager.autopager(raw_control_chars=raw_cc):
+            print_misspellings(ctxt)
+    except lib.pager.Error:
+        if options.traceback:
+            raise
+        msg = f'{ap.prog}: pager failed'
+        print(msg, file=sys.stderr)
+        rc = 1
     sys.exit(rc)
 
 def spellcheck_file(ctxt, file):
@@ -184,7 +193,7 @@ def spellcheck_file(ctxt, file):
     for line in file:
         if force_ucs2:
             # https://github.com/rfk/pyenchant/issues/58
-            line = ''.join(c if c <= '\uFFFF' else '\uFFFD' for c in line)
+            line = re.sub(r'[^\0-\uFFFF]', '\uFFFD', line)
         line = line.strip()
         line = line.expandtabs()
         taken = bytearray(len(line))
@@ -235,7 +244,8 @@ def print_common_misspellings(ctxt):
         if options.suggest > 0:
             suggestions = ctxt.dictionary.suggest(word)[:options.suggest]
             if suggestions:
-                extra = ' ({sug})'.format(sug=', '.join(suggestions))
+                suggestions = str.join(', ', suggestions)
+                extra = f' ({suggestions})'
         print(word + extra + ':')
         highlight_color = 'error' if occurrences.certainty > 0 else 'warn'
         occurrences = [
@@ -257,11 +267,7 @@ def print_common_misspellings(ctxt):
                 print(lib.colors.dim('|'), end=' ')
             else:
                 print('|', end=' ')
-            print('{lc}{word}{rc}'.format(
-                lc=lcontext,
-                word=word,
-                rc=rcontext,
-            ))
+            print(f'{lcontext}{word}{rcontext}')
         if options.output_format != 'color':
             print('', ' ' * lwidth, '^' * len(word))
         if not options.compact:
@@ -284,13 +290,14 @@ def print_rare_misspellings(ctxt):
             if options.suggest > 0:
                 suggestions = ctxt.dictionary.suggest(word)[:options.suggest]
                 if suggestions:
-                    extra = ' ({sug})'.format(sug=', '.join(suggestions))
+                    suggestions = str.join(', ', suggestions)
+                    extra = f' ({suggestions})'
             header += [word + extra]
             for x in positions:
                 underline[x : x + len(word)] = underline_char * len(word)
         if not header:
             continue
-        print(', '.join(header) + ':')
+        print(str.join(', ', header) + ':')
         underline = underline.decode()
         lwidth = len(underline) - len(underline.lstrip())
         rwidth = len(underline) - len(underline.rstrip())
@@ -321,7 +328,7 @@ def print_rare_misspellings(ctxt):
             print()
 
 class list_languages(argparse.Action):
-    def __call__(self, *args, **kwargs):  # pylint: disable=arguments-differ
+    def __call__(self, *args, **kwargs):  # pylint: disable=arguments-differ,signature-differs
         for lang in sorted(enchant.list_languages()):
             print(lang)
         sys.exit(0)
