@@ -1,4 +1,4 @@
-# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -66,8 +66,8 @@ class Macros():
             regex = []
             for i, (name, definition) in enumerate(self._defs.items()):
                 substs += [definition]
-                regex += ['(?P<mwic{i}>{name})'.format(i=i, name=re.escape(name))]
-            regex = '|'.join(regex)
+                regex += [f'(?P<mwic{i}>{re.escape(name)})']
+            regex = str.join('|', regex)
             regex = re.compile(regex)
             self._regex = regex
             self._substs = substs
@@ -75,7 +75,7 @@ class Macros():
         assert self._substs is not None
         def replace(match):
             for i, subst in enumerate(substs):
-                if match.group('mwic{i}'.format(i=i)) is not None:
+                if match.group(f'mwic{i}') is not None:
                     return subst
             assert False  # no coverage
         return self._regex.sub(replace, s)
@@ -89,7 +89,7 @@ class Dictionary():
         while True:
             path = os.path.join(datadir, lang)
             try:
-                file = open(path, 'rt', encoding='UTF-8')
+                file = open(path, 'rt', encoding='UTF-8')  # pylint: disable=consider-using-with
             except FileNotFoundError:
                 [lang, *suffix] = lang.rsplit('-', 1)
                 if suffix:
@@ -116,7 +116,8 @@ class Dictionary():
                     elif line[0][0] == '@':
                         if (len(line) >= 4) and (line[0] == '@define') and (line[2] == '='):
                             (_, name, _, *definition) = line
-                            definition = r'(?:{re})'.format(re=r'\s+'.join(definition))
+                            definition = str.join(r'\s+', definition)
+                            definition = fr'(?:{definition})'
                             try:
                                 re.compile(definition)
                             except re.error as exc:  # no coverage
@@ -124,11 +125,11 @@ class Dictionary():
                             try:
                                 macros[name] = macros.expand(definition)  # pylint: disable=unsubscriptable-object
                             except KeyError:  # no coverage
-                                raise error('duplicate macro definition: {}'.format(name))
+                                raise error(f'duplicate macro definition: {name}')
                         else:
                             raise error('malformed @-command')  # no coverage
                     else:
-                        regex = r'\s+'.join(line)
+                        regex = str.join(r'\s+', line)
                         regex = macros.expand(regex)
                         try:
                             re.compile(regex)
@@ -137,9 +138,8 @@ class Dictionary():
                         regexes += [regex]
             break
         if regexes:
-            regex = r'\b(?:(?i){0})\b'.format(
-                '|'.join(regexes)
-            )
+            regex = str.join('|', regexes)
+            regex = fr'\b(?:(?i){regex})\b'
             self._find = re.compile(regex).finditer
         else:
             self._find = _find_nothing
